==> sail_0.9.9.orig.tar.gz: sail-0.9.9/src/sail-common/compression_level.c <==
/*  This file is part of SAIL (https://github.com/HappySeaFox/sail)

    Copyright (c) 2022 Dmitry Baryshev

    The MIT License

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.
*/

#include "sail-common.h"

sail_status_t sail_alloc_compression_level(struct sail_compression_level **compression_level) {

    SAIL_CHECK_PTR(compression_level);

    void *ptr;
    SAIL_TRY(sail_malloc(sizeof(struct sail_compression_level), &ptr));
    *compression_level = ptr;

    (*compression_level)->min_level     = 0;
    (*compression_level)->max_level     = 0;
    (*compression_level)->default_level = 0;
    (*compression_level)->step          = 0;

    return SAIL_OK;
}

void sail_destroy_compression_level(struct sail_compression_level *compression_level) {

    if (compression_level == NULL) {
        return;
    }

    sail_free(compression_level);
}

==> sail_0.9.10.orig.tar.gz: sail-0.9.10/src/sail-common/compression_level.c <==
/*  This file is part of SAIL (https://github.com/HappySeaFox/sail)

    Copyright (c) 2022 Dmitry Baryshev

    The MIT License

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:

    The above copyright notice and this permission notice shall be included in all
    copies or substantial portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
    AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
    OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
    SOFTWARE.
*/

#include "sail-common.h"

sail_status_t sail_alloc_compression_level(struct sail_compression_level** compression_level)
{
    SAIL_CHECK_PTR(compression_level);

    void* ptr;
    SAIL_TRY(sail_malloc(sizeof(struct sail_compression_level), &ptr));
    *compression_level = ptr;

    (*compression_level)->min_level     = 0;
    (*compression_level)->max_level     = 0;
    (*compression_level)->default_level = 0;
    (*compression_level)->step          = 0;

    return SAIL_OK;
}

void sail_destroy_compression_level(struct sail_compression_level* compression_level)
{
    if (compression_level == NULL)
    {
        return;
    }

    sail_free(compression_level);
}
